canossa invisible screen engine
===============================

Install
-------

via github ::

    $ git clone --recursive https://github.com/saitoha/canossa.git
    $ cd canossa
    $ python setup.py install

or via pip ::

    $ pip install canossa


Usage
-----

Comming soon.

Dependencies
------------

 - termprop
   https://github.com/saitoha/termprop

 - TFF - Terminal Filter Framework
   https://github.com/saitoha/tff

Dependents
----------

 - sentimental-skk
   https://github.com/saitoha/sentimental-skk


